==> openturns_1.3.orig.tar.bz2: openturns-1.3/lib/test/t_NumericalMathFunction_composition.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_composition.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  Copyright (C) 2005-2014 Airbus-EDF-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try
  {

    /** Left hand side of the composition */
    Description input(2);
    input[0] = "x1";
    input[1] = "x2";
    Description output(3);
    output[0] = "y1";
    output[1] = "y2";
    output[2] = "y3";
    Description formula(3);
    formula[0] = "x1*sin(x2)";
    formula[1] = "cos(x1+x2)";
    formula[2] = "(x2+1)*exp(x1-2*x2)";
    NumericalMathFunction left(input, output, formula);

    /** Right hand side of the composition */
    Description input_r(4);
    input_r[0] = "x1";
    input_r[1] = "x2";
    input_r[2] = "x3";
    input_r[3] = "x4";
    Description output_r(2);
    output_r[0] = "y1";
    output_r[1] = "y2";
    Description formula_r(2);
    formula_r[0] = "(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)";
    formula_r[1] = "cos(x2*x2+x4)/(x1*x1+1+x3^4)";
    NumericalMathFunction right(input_r, output_r, formula_r);

    /** Compositon of left and right */
    NumericalMathFunction composed(ComposedNumericalMathFunction(left, right));

    fullprint << "right=" << right << std::endl;
    fullprint << "left=" << left << std::endl;
    fullprint << "composed=" << composed << std::endl;

    /** Does it worked? */
    NumericalPoint x(right.getInputDimension(), 1.0);
    NumericalPoint y(right(x));
    NumericalPoint z(left(y));
    Matrix Dy(right.gradient(x));
    Matrix Dz(left.gradient(y));

    fullprint << "x=" << x << " y=right(x)=" << y << " z=left(y)=" << z << std::endl;
    fullprint << "left(right(x))=" << composed(x) << std::endl;
    fullprint << "D(right)(x)=" << Dy << " D(left)(y)=" << Dz;
    fullprint << " prod=" << Dy * Dz << std::endl;
    fullprint << "D(left(right(x)))=" << composed.gradient(x) << std::endl;
    SymmetricTensor result(composed.hessian(x));
    fullprint << "DD(left(right(x)))=" << std::endl;
    for(UnsignedLong k = 0; k < result.getNbSheets(); k++)
    {
      for(UnsignedLong j = 0; j < result.getNbColumns(); j++)
      {
        for(UnsignedLong i = 0; i < result.getNbRows(); i++)
        {
          fullprint << std::setw(14) << std::scientific << std::right << result(i, j, k);
        }
        fullprint << std::endl;
      }
      fullprint << std::endl;
    }
    for (UnsignedLong i = 0; i < composed.getOutputDimension(); ++i)
    {
      fullprint << "Marginal " << i << "=" << composed.getMarginal(i) << std::endl;
    }
    Indices indices(2);
    indices[0] = 0;
    indices[1] = 1;
    fullprint << "Marginal (0,1)=" << composed.getMarginal(indices) << std::endl;
    indices[0] = 0;
    indices[1] = 2;
    fullprint << "Marginal (0,2)=" << composed.getMarginal(indices) << std::endl;
    indices[0] = 1;
    indices[1] = 2;
    fullprint << "Marginal (1,2)=" << composed.getMarginal(indices) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.5.orig.tar.bz2: openturns-1.5/lib/test/t_NumericalMathFunction_composition.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NumericalMathFunction_composition.cxx
 *  @brief The test file of class NumericalMathFunction for standard methods
 *
 *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try
  {

    /** Left hand side of the composition */
    Description input(2);
    input[0] = "x1";
    input[1] = "x2";
    Description output(3);
    output[0] = "y1";
    output[1] = "y2";
    output[2] = "y3";
    Description formula(3);
    formula[0] = "x1*sin(x2)";
    formula[1] = "cos(x1+x2)";
    formula[2] = "(x2+1)*exp(x1-2*x2)";
    NumericalMathFunction left(input, output, formula);

    /** Right hand side of the composition */
    Description input_r(4);
    input_r[0] = "x1";
    input_r[1] = "x2";
    input_r[2] = "x3";
    input_r[3] = "x4";
    Description output_r(2);
    output_r[0] = "y1";
    output_r[1] = "y2";
    Description formula_r(2);
    formula_r[0] = "(x1*x1+x2^3*x1)/(2*x3*x3+x4^4+1)";
    formula_r[1] = "cos(x2*x2+x4)/(x1*x1+1+x3^4)";
    NumericalMathFunction right(input_r, output_r, formula_r);

    /** Compositon of left and right */
    NumericalMathFunction composed(ComposedNumericalMathFunction(left, right));

    fullprint << "right=" << right << std::endl;
    fullprint << "left=" << left << std::endl;
    fullprint << "composed=" << composed << std::endl;

    /** Does it worked? */
    NumericalPoint x(right.getInputDimension(), 1.0);
    NumericalPoint y(right(x));
    NumericalPoint z(left(y));
    Matrix Dy(right.gradient(x));
    Matrix Dz(left.gradient(y));

    fullprint << "x=" << x << " y=right(x)=" << y << " z=left(y)=" << z << std::endl;
    fullprint << "left(right(x))=" << composed(x) << std::endl;
    fullprint << "D(right)(x)=" << Dy << " D(left)(y)=" << Dz;
    fullprint << " prod=" << Dy * Dz << std::endl;
    fullprint << "D(left(right(x)))=" << composed.gradient(x) << std::endl;
    SymmetricTensor result(composed.hessian(x));
    fullprint << "DD(left(right(x)))=" << std::endl;
    for(UnsignedInteger k = 0; k < result.getNbSheets(); k++)
    {
      for(UnsignedInteger j = 0; j < result.getNbColumns(); j++)
      {
        for(UnsignedInteger i = 0; i < result.getNbRows(); i++)
        {
          fullprint << std::setw(14) << std::scientific << std::right << result(i, j, k);
        }
        fullprint << std::endl;
      }
      fullprint << std::endl;
    }
    for (UnsignedInteger i = 0; i < composed.getOutputDimension(); ++i)
    {
      fullprint << "Marginal " << i << "=" << composed.getMarginal(i) << std::endl;
    }
    Indices indices(2);
    indices[0] = 0;
    indices[1] = 1;
    fullprint << "Marginal (0,1)=" << composed.getMarginal(indices) << std::endl;
    indices[0] = 0;
    indices[1] = 2;
    fullprint << "Marginal (0,2)=" << composed.getMarginal(indices) << std::endl;
    indices[0] = 1;
    indices[1] = 2;
    fullprint << "Marginal (1,2)=" << composed.getMarginal(indices) << std::endl;

  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
